@@ -1,9 +1,9 @@
 from __future__ import unicode_literals, division, absolute_import
+import codecs
 import logging
 
 from flexget import options
 from flexget.event import event
-from flexget.task import Task
 
 log = logging.getLogger('check')
 
@@ -11,7 +11,7 @@ log = logging.getLogger('check')
 @event('manager.before_config_load')
 def pre_check_config(manager):
     if manager.options.cli_command == 'check':
-        with open(manager.config_path) as config:
+        with codecs.open(manager.config_path, 'r', 'utf-8') as config:
             manager.pre_check_config(config.read())
 
 def check(manager, options):
